/***************************************************************************
 *   copyright            : (C) 1999 by Daniel Reith                       *
 *   email                : DanR@gmx.de                                    *
 *                                                                         *
 *   copyright           : (C) 2003 by Hendrik Sattler                     *
 *   mail                : pingos@hendrik-sattler.de                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef AUSWAHL_H
#define AUSWAHL_H

#include "info.h"
#include <wx/wx.h>

enum {
 LL = 105,
 KL,
 CS
};

class Auswahldialog : public wxDialog {
 public:
  Auswahldialog(wxWindow* parent, wxWindowID id,
		const wxString& title, const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize, long style = wxDEFAULT_DIALOG_STYLE,
		const wxString& name = _T("dialogBox"));
  ~Auswahldialog();
  void OnButton(wxCommandEvent& event);

 private:
  wxButton* btnLL;
  wxButton* btnKL;
  wxButton* btnCS;
  wxButton* btnCancel;
  wxBitmap* logo;

  DECLARE_EVENT_TABLE()
};

#endif
